Overview
========

Dj-Hitcount allows you to track the number of hits (views) for a particular object. This isn’t meant to be a full-fledged tracking application or a real analytic tool; it's just a basic hit counter.

How one tracks a "hit" or "view" of a web page is not such a simple thing as it might seem.  That's why folks rely on Google Analytics or similar tools.  It's tough!  This is a simple app with some settings and features that should suit the basic needs of smaller sites.

It comes ready to track hits with a ``HitCountDetailView`` and a ``HitCountJSONView`` (to use the out-of-the-box JavaScript method, you will need jQuery -- although writing your own JavaScript implementation may not be hard).

Migrating from ``django-hitcount``
----------------------------------

Please see the :ref:`guidelines for migration<migrating from django-hitcount>`.
